man > watch(1)

TLDR: watch (tldr-pages)

Execute a program periodically and monitor the output in full-screen mode.

  • Repeatedly run a command and show the result
    watch {{command}}
  • Re-run a command every 60 seconds
    watch {{-n|--interval}} 60 {{command}}
  • Monitor disk space, highlighting differences as they appear
    watch {{-d|--differences}} df
  • Repeatedly run a pipeline and show the result
    watch "{{command1}} | {{command2}} | {{command3}}"
  • Exit `watch` if the visible output changes
    watch {{-g|--chgexit}} {{lsblk}}
  • Interpret terminal control characters
    watch {{-c|--color}} {{ls --color=always}}
WATCH(1)                                    User Commands                                   WATCH(1)

NAME
       watch - execute a program periodically, showing output fullscreen

SYNOPSIS
       watch [options] command

DESCRIPTION
       watch runs command repeatedly, displaying its output and errors (the first screenfull).  This
       allows  you to watch the program output change over time.  By default, command is run every 2
       seconds and watch will run until interrupted.

OPTIONS
       -b, --beep
              Beep if command has a non-zero exit.

       -c, --color
              Interpret ANSI color and style sequences.

       -C, --no-color
              Do not interpret ANSI color and style sequences.

       -d, --differences[=permanent]
              Highlight the differences between successive updates. If the optional permanent  argu‐
              ment is specified then watch will show all changes since the first iteration.

       -e, --errexit
              Freeze updates on command error, and exit after a key press.

       -g, --chgexit
              Exit when the output of command changes.

       -n, --interval seconds
              Specify update interval.  The command will not allow quicker than 0.1 second interval,
              in  which the smaller values are converted. Both '.' and ',' work for any locales. The
              WATCH_INTERVAL environment can be used to  persistently  set  a  non-default  interval
              (following the same rules and formatting).

       -p, --precise
              Make  watch  attempt to run command every --interval seconds.  Try it with ntptime (if
              present) and notice how the fractional seconds stays (nearly) the same, as opposed  to
              normal mode where they continuously increase.

       -q, --equexit <cycles>
              Exit when output of command does not change for the given number of cycles.

       -r, --no-rerun
              Do not run the program on terminal resize, the output of the program will re-appear at
              the next regular run time.

       -t, --no-title
              Turn  off the header showing the interval, command, and current time at the top of the
              display, as well as the following blank line.

       -w, --no-wrap
              Turn off line wrapping. Long lines will be truncated instead of wrapped  to  the  next
              line.

       -x, --exec
              Pass  command  to exec(2) instead of sh -c which reduces the need to use extra quoting
              to get the desired effect.

       -h, --help
              Display help text and exit.

       -v, --version
              Display version information and exit.

EXIT STATUS
              0      Success.
              1      Various failures.
              2      Forking the process to watch failed.
              3      Replacing child process stdout with write side pipe failed.
              4      Command execution failed.
              5      Closing child process write pipe failed.
              7      IPC pipe creation failed.
              8      Getting child process return value with waitpid(2) failed, or command exited up
                     on error.
              other  The watch will propagate command exit status as child exit status.
ENVIRONMENT
       The behavior of watch is affected by the following environment variables.

       WATCH_INTERVAL
              Update interval, follows the same rules as the --interval command line option.

NOTES
       POSIX option processing is used (i.e., option processing stops at the first non-option  argu‐
       ment).  This means that flags after command don't get interpreted by watch itself.

BUGS
       Upon terminal resize, the screen will not be correctly repainted until the next scheduled up‐
       date.  All --differences highlighting is lost on that update as well. When using the --no-re‐
       run option, no output of will be visible.

       Non-printing  characters are stripped from program output.  Use cat -v as part of the command
       pipeline if you want to see them.

       Combining Characters that are supposed to display on the character at the last column on  the
       screen may display one column early, or they may not display at all.

       Combining Characters never count as different in --differences mode.  Only the base character
       counts.

       Blank lines directly after a line which ends in the last column do not display.

       --precise  mode  doesn't yet have advanced temporal distortion technology to compensate for a
       command that takes more than --interval seconds to execute.  watch also can get into a  state
       where it rapid-fires as many executions of command as it can to catch up from a previous exe‐
       cutions running longer than --interval (for example, netstat(8) taking ages on a DNS lookup).

EXAMPLES
       To watch for mail, you might do
              watch -n 60 from
       To watch the contents of a directory change, you could use
              watch -d ls -l
       If you're only interested in files owned by user joe, you might use
              watch -d 'ls -l | fgrep joe'
       To see the effects of quoting, try these out
              watch echo $$
              watch echo '$$'
              watch echo "'"'$$'"'"
       To see the effect of precision time keeping, try adding -p to
              watch -n 10 sleep 1
       You can watch for your administrator to install the latest kernel with
              watch uname -r
       (Note  that -p isn't guaranteed to work across reboots, especially in the face of ntpdate (if
       present) or other bootup time-changing mechanisms)

REPORTING BUGS
       Please send bug reports to ]8;;procps AT freelists.org\procps AT freelists.org]8;;\

procps-ng                                    2023-01-17                                     WATCH(1)
watch(1)
NAME SYNOPSIS DESCRIPTION OPTIONS
-b, --beep -c, --color -C, --no-color -d, --differences[=permanent] -e, --errexit -g, --chgexit -n, --interval seconds -p, --precise -q, --equexit -r, --no-rerun -t, --no-title -w, --no-wrap -x, --exec -h, --help -v, --version
EXIT STATUS ENVIRONMENT NOTES BUGS EXAMPLES REPORTING BUGS

Generated by phpman v4.10.0-7-g98e9fd5 · Markdown · JSON · MCP Author: Che Dong Under GNU General Public License
2026-09-12 06:57 @2600:1f28:365:80b0:6f72:a904:73b0:e266
CrawledBy CCBot/2.0 (https://commoncrawl.org/faq/)
Valid XHTML 1.0 Transitional!Valid CSS!

^_top_^